package com.inspect.metadata.montdata.service.impl;

import com.inspect.metadata.montdata.domain.BasedataMontNestStaData;
import com.inspect.metadata.montdata.mapper.BasedataMontNestStaDataMapper;
import com.inspect.metadata.montdata.service.IBasedataMontNestStaDataService;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;

@Service
public class BasedataMontNestStaDataServiceImpl implements IBasedataMontNestStaDataService {
    @Resource
    private BasedataMontNestStaDataMapper basedataMontNeststadataMapper;

    public BasedataMontNestStaData selectBasedataMontNestStaDataByMontNestStaDataId(Long montNestStaDataId) {
        return this.basedataMontNeststadataMapper.selectBasedataMontNestStaDataByMontNestStaDataId(montNestStaDataId);
    }

    public List<BasedataMontNestStaData> selectBasedataMontNestStaDataList(BasedataMontNestStaData basedataMontNeststadata) {
        return this.basedataMontNeststadataMapper.selectBasedataMontNestStaDataList(basedataMontNeststadata);
    }

    public int insertBasedataMontNestStaData(BasedataMontNestStaData basedataMontNeststadata) {
        return this.basedataMontNeststadataMapper.insertBasedataMontNestStaData(basedataMontNeststadata);
    }

    public int updateBasedataMontNestStaData(BasedataMontNestStaData basedataMontNeststadata) {
        return this.basedataMontNeststadataMapper.updateBasedataMontNestStaData(basedataMontNeststadata);
    }

    public int deleteBasedataMontNestStaDataByMontNestStaDataIds(Long[] montNestStaDataIds) {
        return this.basedataMontNeststadataMapper.deleteBasedataMontNestStaDataByMontNestStaDataIds(montNestStaDataIds);
    }

    public int deleteBasedataMontNestStaDataByMontNestStaDataId(Long montNestStaDataId) {
        return this.basedataMontNeststadataMapper.deleteBasedataMontNestStaDataByMontNestStaDataId(montNestStaDataId);
    }
}
